@@ -24,8 +24,8 @@
 ####### TAKE CARE: JUST PARTS _IN RED_ SOULD TO BE SAFELY EDITABLE! ########
 
 @varn = ( [ [1, 2, 3] ] ); # VARIABLE NUMBERS. THE PROGRAM TRIPLES THE SERIES: IT TRANSFORMS IT IN 1, 2, 3, 1, 2, 3, 1, 2, 3.
-@midvalues = (2, 2, 2); # POINT TO POINT CORRENSPODENCE WITH THE ABOVE. THE MID ITERATION NUMBER FOR EACH PARAMETER.
-# I.E. THREE ITERATION PER PARAMETER, VALUE "2" FOR EACH $midvalue (@midvalues). 
+@midvalues = (2, 2, 2); # POINT TO POINT CORRENSPODENCE WITH THE ABOVE, and with the variables $setvar (see below). THE MID ITERATION NUMBER FOR EACH PARAMETER. 
+# I.E. IF THERE ARE 3 ITERATION PER PARAMETER, A VALUE "2" FOR EACH $midvalue (@midvalues) HAS TO BE SPECIFIED. 
 
 @casegroup = ( [ [3, 2], [4, 2] ] ) ; # BETWEEN SQUARE BRACKETS ARE THE BLOCKS OF BLOCK COORDINATE SEARCH. THE FIRST ITEM IN 
 # EACH SQUARE BRACKET IS THE POSITION OF THE FIRST ITEM IN THE ACTIVE BLOCK (INDEX FROM 0). THE SECOND ITEM IS THE DIMENSION OF THE ACTIVE BLOCK,
@@ -127,7 +127,7 @@ $simnetwork =
 # THE FIRST ITEM OF EACH PAIR IS THE OBJECTIVE FUNCTION NAME AND THE SECOND IS THE OBJECTIVE FUNCTION.
 
 @weights = ( 0.5, 0.5); 
-# RATIO OF EACH OBJECTIVE FUNCTION OVER THE TOTAL OF ONE.
+# RATIO OF EACH OBJECTIVE FUNCTION, OVER THE TOTAL OF 1.
 
 @weightsaim = (1, -1); 
 # THERE IS A POINT TO POINT CORRENSPONDENCE WITH THE ABOVE ARRAY. A (-1) VALUE TELLS THE PROGRAM THAT THE OBJECTIVE FOR THAT OBJECTIVE FUNCTION IS MINIMIZATION. 
@@ -184,11 +184,6 @@ $reportloadsdata = [[$simtitle[0], $simtitle[1]],
 
 ################# HERE THE MORPHING VARIABLES FOLLOW ###################
 
-@varnumbers = (
- 1, 2 
-);   #  THIS DATUM IS OF THE GREATEST IMPORTANCE. IT SPECIFIES THE CYCLE SEQUENCE. THE NUMBERS MENTION THE VARIABLES TO BE CHECKED. EXAMPLE: (1, 10, 5, 2, 4.)
-
-
 ############################## HERE FOLLOWS THE DESCRIPTION OF MORPHING PHASE 1. 
 $stepsvar1 =
 3
